<?php

namespace Drupal\tome_static;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderInterface;
use Drupal\tome_static\EventSubscriber\LanguagePathSubscriber;
use Drupal\tome_static\EventSubscriber\RedirectPathSubscriber;
use Drupal\tome_static\PageCache\RequestPolicy\DynamicRequestPolicy;
use Symfony\Component\DependencyInjection\Reference;

/**
 * Registers services in the container.
 */
class TomeStaticServiceProvider implements ServiceProviderInterface {

  /**
   * {@inheritdoc}
   */
  public function register(ContainerBuilder $container) {
    $modules = $container->getParameter('container.modules');
    if (isset($modules['language'])) {
      $container->register('tome_static.language_path_subscriber', LanguagePathSubscriber::class)
        ->addTag('event_subscriber')
        ->addArgument(new Reference('config.factory'))
        ->addArgument(new Reference('language_manager'));
    }
    if (isset($modules['redirect'])) {
      $container->register('tome_static.redirect_path_subscriber', RedirectPathSubscriber::class)
        ->addTag('event_subscriber')
        ->addArgument(new Reference('entity_type.manager'))
        ->addArgument(new Reference('language_manager'));
    }
    if (isset($modules['dynamic_page_cache'])) {
      $container->register('tome_static.dynamic_page_cache_request_policy', DynamicRequestPolicy::class)
        ->setDecoratedService('dynamic_page_cache_request_policy');
    }
  }

}
